
============================
M-Star CFD Python Post
============================

This package contains post-processing utilities to help interact with M-Star CFD output VTK files

The following scripts/commands are available -- 

- ``mstar-convert-particles`` - convert particle data to CSV and Apache Parquet formats
- ``mstar-batch-post`` - run batch post-processing using JSON input file
- ``mstar-stats-gui`` - a basic Qt based GUI that can quickly show the ``Stats/`` output data

